Learn R Programming

bnpmr (version 1.1)

bnpmr-package: Monotonic Regression

Description

Implements the Bayesian monotonic regression method described in Bornkamp and Ickstadt (2009)

Arguments

Details

Package: bnpmr
Type: Package
Version: 1.1
Date: 2013-05-02
License: GPL
LazyLoad: yes

References

Bornkamp, B., Ickstadt, K. (2009). Bayesian nonparametric estimation of continuous monotone functions with applications to dose-response analysis. Biometrics, 65, 198-205.

See Also

pred.bnpmr, bnpmr